/*
 * Click nbfs://nbhost/SystemFileSystem/Templates/Licenses/license-default.txt to change this license
 * Click nbfs://nbhost/SystemFileSystem/Templates/Classes/Class.java to edit this template
 */

package métiers;

import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/**
 *
 * @author ilona
 */
public class Commande {
    
private int noCom, noVendeur;
private String dateCom;


private final HashMap<Instrument, Integer> lesLignes = new HashMap<>(); 


    public Commande(int noCom, int noVendeur, String dateCom) {
        this.noCom = noCom;
        this.noVendeur = noVendeur;
        this.dateCom = dateCom;
    }


    /**
    * Ajoute une quantité donnée d'un instrument à la commande
    * @param unInstrument instrument à ajouter
    * @param qte quantité à ajouter 
    * @return true si l'ajout est bon
    */
    public boolean ajouter(Instrument unInstrument, int qte){
        //il faut gérer l'ajout d'un instrument existant dans la commande, ce sera une mise à jour de la ligne
        //il faut empêcher l'ajout d'une ligne avec une quantité à 0
        //bien s'assurer que le stock est suffisant
        boolean ajoutOK;
        int qteDisponible = unInstrument.getQteStock();
        if (qteDisponible<qte){
            ajoutOK = false;
        }else {
            ajoutOK = true;
            lesLignes.put(unInstrument,qte);
            unInstrument.setQteStock(qteDisponible-qte);
        }
        return ajoutOK;
    }
    /**
    * Supprimer un instrument de la commande
    * @param unInstrument instrument à supprimer
    * @return true si la suppression est effectuée
    */
    public boolean supprimer(Instrument unInstrument){
        //lesLignes.remove(unInstrument);
        boolean suppOK;
        if (lesLignes.containsKey(unInstrument) == true){
            suppOK = true;
            lesLignes.remove(unInstrument);
        } else {
            suppOK = false;
        }
        return suppOK;
    }
   
/////////////////////////////////////////////////////////////////////////////////
    
    public int getNoCom() {
        return noCom;
    }

    public int getNoVendeur() {
        return noVendeur;
    }

    public String getDateCom() {
        return dateCom;
    }

    public HashMap<Instrument, Integer> getLesLignes() {
        return lesLignes;
    }
    

    public void setNoCom(int noCom) {
        this.noCom = noCom;
    }

    public void setNoVendeur(int noVendeur) {
        this.noVendeur = noVendeur;
    }

    public void setDateCom(String dateCom) {
        this.dateCom = dateCom;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Commande other = (Commande) obj;
        if (this.noCom != other.noCom) {
            return false;
        }
        if (this.noVendeur != other.noVendeur) {
            return false;
        }
        return Objects.equals(this.dateCom, other.dateCom);
    }
    
    
}
